import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_dynamodb._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kinesis._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_msk._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_notifications._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sns_subscriptions._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-lambda-event-sources",
    "1.95.2",
    __name__[0:-6],
    "aws-lambda-event-sources@1.95.2.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
